base_emoji

Types

pub type MapVersion {
  V1
}

Constructors

  • V1

Values

pub fn encode(bits b: BitArray) -> String

Encodes the given bit array with the latest emoji map.

pub fn encode_with_version(
  bits b: BitArray,
  version v: MapVersion,
) -> String

Encodes the given bit array with the requested emoji map. Unless you need a constant display, encode should be preferred to get the latest map, which attempts to maximize the visual difference between two arrays.

Search Document